/* eslint-disable @typescript-eslint/no-explicit-any */
import { formatAddItem, handleFindDomById } from "@/utils/index";
import type { IWidget, IWidgetJson } from '@/types/widgetsConfigInterface'

/**
 * 新增表格 默认会自动生成一个单元格
 * @param widgetJson
 * @param addItemTypeName
 * @param fatherId
 */
export const addTable = (widgetJson: IWidgetJson, addItemTypeName: any) => {
  const tableCol = formatAddItem('table-cell');
  const { addItemData, activeId, activeDisplayName } = formatAddItem(addItemTypeName);
  if (addItemData && tableCol['addItemData']) {
    addItemData['subDomList'] = [[tableCol['addItemData']]];
  }
  if (widgetJson['activeConfig']['activeId']) {
    if (widgetJson['activeConfig']['activeId'].startsWith('table-cell')) {
      // 单元格里面直接加
      const tableJson = handleFindDomById(widgetJson['subDomList'], widgetJson['activeConfig']['activeId'], false);
      if (tableJson && addItemData) {
        (tableJson['subDomList'] as IWidget[]).push(addItemData)
      }
    } else if (widgetJson['activeConfig']['activeId'].startsWith('table')) {
      // 表格后面加
      if (addItemData) {
        widgetJson['subDomList'].push(addItemData)
      }
    } else {
      // 寻找上一层单元格加
      const tableJson = handleFindDomById(widgetJson['subDomList'], widgetJson['activeConfig']['activeId'], true);
      if (tableJson && addItemData) {
        (tableJson['subDomList'] as IWidget[]).push(addItemData)
      }
    }
  } else {
    if (addItemData) {
      widgetJson['subDomList'].push(addItemData)
    }
  }
  widgetJson['activeConfig']['activeId'] = tableCol['activeId']
  widgetJson['activeConfig']['activeDisplayName'] = tableCol['activeDisplayName']
  // widgetJson['activeConfig']['activeId'] = activeId
  // widgetJson['activeConfig']['activeDisplayName'] = activeDisplayName
}


/**
 * 新增表格行 以第一列的个数为准
 * @param widgetJson
 * @param addItemTypeName
 * @param fatherId
 */
export const addTableRow = (widgetJson: IWidgetJson, addItemTypeName = 'table-cell') => {
  const tableJson = handleFindDomById(widgetJson['subDomList'], widgetJson['activeConfig']['activeId'], false);
  if (tableJson) {
    const newRow: IWidget[] = []
    for (let index = 0; index < tableJson['subDomList'][0]['length']; index++) {
      const { addItemData } = formatAddItem(addItemTypeName);
      if (addItemData) {
        newRow.push(addItemData);
      }
    }
    (tableJson['subDomList'] as IWidget[][]).push(newRow)
  }
}

/**
 * 新增表格列 遍历每一行增加
 * @param widgetJson
 * @param addItemTypeName
 * @param fatherId
 */
export const addTableCol = (widgetJson: IWidgetJson, addItemTypeName = 'table-cell') => {
  const tableJson = handleFindDomById(widgetJson['subDomList'], widgetJson['activeConfig']['activeId'], false);
  if (tableJson && tableJson['subDomList']) {
    for (let index = 0; index < tableJson['subDomList']['length']; index++) {
      const { addItemData } = formatAddItem(addItemTypeName);
      if (addItemData) {
        const row: IWidget[] = tableJson['subDomList'][index];
        row.push(addItemData);
      }
    }
  }
}